@@ -579,13 +579,20 @@ var app = new Vue({
 
         prepareSaveItem: function ( item, schema ) {
             var copy = JSON.parse( JSON.stringify( item ) );
-            for ( var k in copy ) {
-                if ( schema.properties[k].readOnly ) {
+            for ( var k in schema.properties ) {
+                var prop = schema.properties[k];
+                if ( prop.readOnly ) {
                     delete copy[k];
                 }
-                else if ( schema.properties[k].format == 'markdown' ) {
-                    if ( schema.properties[k]['x-html-field'] ) {
-                        copy[ schema.properties[k]['x-html-field'] ]
+                else if (
+                    ( prop.type == 'boolean' || prop.type[0] == 'boolean' )
+                    && !copy[k]
+                ) {
+                    copy[k] = false;
+                }
+                else if ( prop.format == 'markdown' ) {
+                    if ( prop['x-html-field'] ) {
+                        copy[ prop['x-html-field'] ]
                             = marked( copy[k], { sanitize: true });
                     }
                 }
