@@ -1,5 +1,5 @@
 package Yancy::Backend::Mysql;
-our $VERSION = '1.011';
+our $VERSION = '1.012';
 # ABSTRACT: A backend for MySQL using Mojo::mysql
 
 #pod =head1 SYNOPSIS
@@ -144,6 +144,7 @@ sub _id_field {
 
 sub create {
     my ( $self, $coll, $params ) = @_;
+    $self->_normalize( $coll, $params );
     my $id_field = $self->_id_field( $coll );
     my $id = $self->mysql->db->insert( $coll, $params )->last_insert_id;
     # Assume the id field is correct in case we're using a different
@@ -153,6 +154,7 @@ sub create {
 
 sub create_p {
     my ( $self, $coll, $params ) = @_;
+    $self->_normalize( $coll, $params );
     my $id_field = $self->_id_field( $coll );
     return $self->mysql->db->insert_p( $coll, $params )
         ->then( sub { $params->{ $id_field } || shift->last_insert_id } );
@@ -217,12 +219,14 @@ sub list_p {
 
 sub set {
     my ( $self, $coll, $id, $params ) = @_;
+    $self->_normalize( $coll, $params );
     my $id_field = $self->_id_field( $coll );
     return !!$self->mysql->db->update( $coll, $params, { $id_field => $id } )->rows;
 }
 
 sub set_p {
     my ( $self, $coll, $id, $params ) = @_;
+    $self->_normalize( $coll, $params );
     my $id_field = $self->_id_field( $coll );
     return $self->mysql->db->update_p( $coll, $params, { $id_field => $id } )
         ->then( sub { !!shift->rows } );
@@ -241,6 +245,28 @@ sub delete_p {
         ->then( sub { !!shift->rows } );
 }
 
+sub _normalize {
+    my ( $self, $coll, $data ) = @_;
+    my $schema = $self->collections->{ $coll }{ properties };
+    for my $key ( keys %$data ) {
+        my $type = $schema->{ $key }{ type };
+        # Boolean: true (1, "true"), false (0, "false")
+        if ( _is_type( $type, 'boolean' ) ) {
+            $data->{ $key }
+                = $data->{ $key } && $data->{ $key } !~ /^false$/i
+                ? 1 : 0;
+        }
+    }
+}
+
+sub _is_type {
+    my ( $type, $is_type ) = @_;
+    return unless $type;
+    return ref $type eq 'ARRAY'
+        ? !!grep { $_ eq $is_type } @$type
+        : $type eq $is_type;
+}
+
 sub read_schema {
     my ( $self ) = @_;
     my $database = $self->mysql->db->query( 'SELECT DATABASE()' )->array->[0];
@@ -274,6 +300,7 @@ ENDQ
     my $columns_q = <<ENDQ;
 SELECT * FROM information_schema.columns
 WHERE table_schema=?
+ORDER BY ORDINAL_POSITION
 ENDQ
 
     my @columns = @{ $self->mysql->db->query( $columns_q, $database )->hashes };
@@ -342,7 +369,7 @@ Yancy::Backend::Mysql - A backend for MySQL using Mojo::mysql
 
 =head1 VERSION
 
-version 1.011
+version 1.012
 
 =head1 SYNOPSIS
 
