@@ -1,5 +1,5 @@
 package Yancy::Backend::Sqlite;
-our $VERSION = '1.011';
+our $VERSION = '1.012';
 # ABSTRACT: A backend for SQLite using Mojo::SQLite
 
 #pod =head1 SYNOPSIS
@@ -140,6 +140,7 @@ sub new {
 
 sub create {
     my ( $self, $coll, $params ) = @_;
+    $self->_normalize( $coll, $params );
     my $id_field = $self->collections->{ $coll }{ 'x-id-field' } || 'id';
     my $inserted_id = $self->sqlite->db->insert( $coll, $params )->last_insert_id;
     # SQLite does not have a 'returning' syntax. Assume id field is correct
@@ -177,6 +178,7 @@ sub list {
 
 sub set {
     my ( $self, $coll, $id, $params ) = @_;
+    $self->_normalize( $coll, $params );
     my $id_field = $self->collections->{ $coll }{ 'x-id-field' } || 'id';
     return !!$self->sqlite->db->update( $coll, $params, { $id_field => $id } )->rows;
 }
@@ -187,6 +189,28 @@ sub delete {
     return !!$self->sqlite->db->delete( $coll, { $id_field => $id } )->rows;
 }
 
+sub _normalize {
+    my ( $self, $coll, $data ) = @_;
+    my $schema = $self->collections->{ $coll }{ properties };
+    for my $key ( keys %$data ) {
+        my $type = $schema->{ $key }{ type };
+        # Boolean: true (1, "true"), false (0, "false")
+        if ( _is_type( $type, 'boolean' ) ) {
+            $data->{ $key }
+                = $data->{ $key } && $data->{ $key } !~ /^false$/i
+                ? 1 : 0;
+        }
+    }
+}
+
+sub _is_type {
+    my ( $type, $is_type ) = @_;
+    return unless $type;
+    return ref $type eq 'ARRAY'
+        ? !!grep { $_ eq $is_type } @$type
+        : $type eq $is_type;
+}
+
 sub read_schema {
     my ( $self ) = @_;
     my %schema;
@@ -308,7 +332,7 @@ Yancy::Backend::Sqlite - A backend for SQLite using Mojo::SQLite
 
 =head1 VERSION
 
-version 1.011
+version 1.012
 
 =head1 SYNOPSIS
 
